Inter-comparison of model and gridded observations of the ocean is a challenge when they use different grids. 
Interpolation from one grid to another brings eventual errors that may affect significantly large scale budgets of tracers (heat, salt, freshwater). 

The PyPAGO suite of programs offers the possibility to analyze gridded ocean data along physical sections with minimum interpolation. 
For example, this allows to monitor the circulation across an observed array in various model outputs, whatever their spatial resolution or type of discretization (B- or C- grids). 
When defining sections that enclose a specific volume, large scale budgets of tracers can be reconstructed and inter-compared among all kinds of gridded ocean data.
